@@ -1,10 +1,11 @@
 /*
-    SPDX-FileCopyrightText: 2015-2024 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2015-2025 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
+#include "config-kdebugsettings.h"
 #include <QApplication>
 
 #include "jobs/changedebugmodejob.h"
@@ -12,8 +13,10 @@
 #include <KAboutData>
 #include <KCrash>
 #include <config-kdebugsettings.h>
-#if HAVE_KDBUSADDONS
+#if WITH_DBUS
 #include <KDBusService>
+#else
+#include <kdsingleapplication.h>
 #endif
 #include <KLocalizedString>
 #include <QCommandLineParser>
@@ -23,30 +26,24 @@
 
 #include <KIconTheme>
 
-#define HAVE_STYLE_MANAGER __has_include(<KStyleManager>)
-#if HAVE_STYLE_MANAGER
 #include <KStyleManager>
-#endif
 
 int main(int argc, char **argv)
 {
     KIconTheme::initTheme();
     QApplication app(argc, argv);
+#if !WITH_DBUS
+    KDSingleApplication sapp;
+#endif
 
     KAboutData aboutData(QStringLiteral("kdebugsettings"),
                          i18n("KDebugSettings"),
                          QStringLiteral(KDEBUGSETTINGS_VERSION),
                          i18n("Configure debug settings"),
                          KAboutLicense::GPL_V2,
-                         i18n("(c) 2015-%1 kdebugsettings authors", QStringLiteral("2024")));
+                         i18n("(c) 2015-%1 kdebugsettings authors", QStringLiteral("2025")));
     aboutData.addAuthor(i18nc("@info:credit", "Laurent Montel"), i18n("Maintainer"), QStringLiteral("montel@kde.org"));
-#if HAVE_STYLE_MANAGER
     KStyleManager::initStyle();
-#else // !HAVE_STYLE_MANAGER
-#if defined(Q_OS_WIN) || defined(Q_OS_MACOS)
-    QApplication::setStyle(QStringLiteral("breeze"));
-#endif
-#endif
     QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("debug-run")));
     KAboutData::setApplicationData(aboutData);
     KCrash::initialize();
@@ -105,8 +102,12 @@ int main(int argc, char **argv)
         }
         return 1;
     } else {
-#if HAVE_KDBUSADDONS
+#if WITH_DBUS
         KDBusService service(KDBusService::Unique);
+#else
+        if (!sapp.isPrimaryInstance()) {
+            return 0;
+        }
 #endif
         auto dialog = new KDebugSettingsDialog;
         const int ret = dialog->exec();
